"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _gatsby = require("gatsby");

var _handleLinkClick = _interopRequireDefault(require("./util/anchor-link/handleLinkClick"));

var _stripHashedLocation = _interopRequireDefault(require("./util/anchor-link/stripHashedLocation"));

var _handleStrippedLinkClick = _interopRequireDefault(require("./util/anchor-link/handleStrippedLinkClick"));

// Copyright (c) 2021 Visiosto oy
// Licensed under the MIT License
// Based on code by Chase Ohlson.
// Original code is available at https://github.com/brohlson/gatsby-plugin-anchor-links.
const propTypes = {
  children: _propTypes.default.node.isRequired,
  className: _propTypes.default.string,
  gatsbyLinkProps: _propTypes.default.shape({
    activeClassName: _propTypes.default.string,
    activeStyle: _propTypes.default.objectOf(_propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])),
    onClick: _propTypes.default.func,
    partiallyActive: _propTypes.default.bool,
    replace: _propTypes.default.bool,
    // eslint-disable-next-line react/forbid-prop-types
    state: _propTypes.default.object,
    to: _propTypes.default.string
  }),
  onAnchorLinkClick: _propTypes.default.func,
  stripHash: _propTypes.default.bool,
  to: _propTypes.default.string.isRequired
};
const defaultProps = {
  className: '',
  gatsbyLinkProps: {},
  onAnchorLinkClick: null,
  stripHash: false
};

function AnchorLink({
  children,
  className,
  gatsbyLinkProps,
  onAnchorLinkClick,
  stripHash,
  to
}) {
  const handleClick = stripHash ? _handleStrippedLinkClick.default : _handleLinkClick.default;
  const linkProps = { ...gatsbyLinkProps,

    /**
     * Spread optional gatsbyLinkProps object in fist, so our specific props will override
     */
    to: stripHash ? (0, _stripHashedLocation.default)(to) : to,
    onClick: event => handleClick(to, event, onAnchorLinkClick)
  };
  /**
   * Optional props
   */

  if (className !== '') {
    linkProps.className = className;
  } // TODO See if the props should be set without spreading
  // eslint-disable-next-line react/jsx-props-no-spreading


  return /*#__PURE__*/_react.default.createElement(_gatsby.Link, linkProps, children);
}

AnchorLink.propTypes = propTypes;
AnchorLink.defaultProps = defaultProps;
var _default = AnchorLink;
exports.default = _default;