"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = handleStrippedLinkClick;

var _errorTypes = _interopRequireDefault(require("./errorTypes"));

var _logWarning = _interopRequireDefault(require("./logWarning"));

var _scroller = _interopRequireDefault(require("./scroller"));

// Copyright (c) 2021 Visiosto oy
// Licensed under the MIT License
// Based on code by Chase Ohlson.
// Original code is available at https://github.com/brohlson/gatsby-plugin-anchor-links.
function handleStrippedLinkClick(to, event, onAnchorLinkClick) {
  /**
   * Log warnings on click
   */
  const improperFormatting = !to.includes('/') || !to.includes('#');

  if (improperFormatting) {
    (0, _logWarning.default)(_errorTypes.default.IMPROPPER_FORMATTING);
  }

  const [anchorPath, anchor] = to.split('#');
  const isBrowser = typeof window !== 'undefined';
  /**
   * Determine location, run scroller or set window variable
   */

  const isSamePage = isBrowser && window.location.pathname === anchorPath;
  const isDifferentPage = isBrowser && window.location.pathname !== anchorPath;

  if (isSamePage) {
    event.preventDefault();
    (0, _scroller.default)(`#${anchor}`, window.visiostoScrollOffset, window.visiostoScrollDuration);
  }

  if (isDifferentPage) {
    window.visiostoScrollHash = `#${anchor}`;
  }

  if (onAnchorLinkClick) {
    onAnchorLinkClick();
  }
}